@@ -19,6 +19,8 @@ class AppConfig(BaseSettings):
     APP_MODULE_PATH: str = "superlinked_app"
     LOG_LEVEL: str = "INFO"
     PERSISTENCE_FOLDER_PATH: str = "in_memory_vdb"
+    SERVER_PORT: int = 8080
+    SERVER_HOST: str = "0.0.0.0"
     DISABLE_RECENCY_SPACE: bool = True
     JSON_LOG_FILE: str | None = None
     LOG_AS_JSON: bool = False
